@@ -1,13 +1,13 @@
+use crate::default_out::dump_undefined_struct;
+use crate::error::BiosParseError;
 use enum_iterator::IntoEnumIterator;
+use smbioslib::*;
 use std::{
     collections::HashSet,
     fmt::{self, Display, Formatter},
     path::PathBuf,
     str::FromStr,
 };
-
-use crate::error::BiosParseError;
-use smbioslib::*;
 use structopt::StructOpt;
 
 #[derive(Debug, StructOpt)]
@@ -210,16 +210,21 @@ impl BiosType {
     // We could make this return something, or, could create a type as a collection containing Vec<BiosType> and
     // then implement methods for that type to perform more advanced I/O via state.
     // More than likely the style of output will be desirable to change (verbose, debug, JSON, etc).
-    pub fn parse_and_display(types: Vec<BiosType>, data: &SMBiosData) {
+    pub fn parse_and_display(types: Vec<BiosType>, data: &SMBiosData, quiet: bool) {
         let unique_types: HashSet<u8> = types
             .iter()
             .flat_map(|bios_type| bios_type.into_iter())
             .collect();
 
+        let mut first = true;
         for undefined_struct in data.iter().filter(|undefined_struct| {
             unique_types.contains(&undefined_struct.header.struct_type())
         }) {
-            println!("{:#X?}", undefined_struct.defined_struct());
+            match first {
+                true => first = false,
+                false => println!(),
+            }
+            dump_undefined_struct(&undefined_struct, data.version, quiet);
         }
     }
 }
